﻿using System;
using System.Xml;
using System.Windows.Forms;

namespace Prova2
{
    public partial class XmlViewerForm : Form
    {
        public XmlViewerForm()
        {
            InitializeComponent();
        }

        private void openToolStripMenuItem_Click(object sender, EventArgs e)
        {
            using (OpenFileDialog openFileDialog = new OpenFileDialog())
            {
                openFileDialog.Filter = "File xml|*.xml";
                openFileDialog.Title = "Selezionare un file xml";
                if (openFileDialog.ShowDialog() == DialogResult.OK)
                {
                    AddXmlDocument(openFileDialog.FileName);
                }
            }
        }

        private void saveAsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            using (SaveFileDialog saveFileDialog = new SaveFileDialog())
            {
                saveFileDialog.Filter = "File xml|*.xml";
                if (saveFileDialog.ShowDialog() == DialogResult.OK)
                {
                    XmlDocument xmlDocument = GetSelectedXmlDocument();
                    xmlDocument.Save(saveFileDialog.FileName);
                }
            }
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void AddXmlDocument(string fileName)
        {
            XmlDocument xmlDocument = new XmlDocument();
            xmlDocument.Load(fileName);
            AddXmlNode(_treeView.Nodes, xmlDocument);
            _treeView.SelectedNode = _treeView.Nodes[_treeView.Nodes.Count - 1];
            saveAsToolStripMenuItem.Enabled = true;
        }

        private void AddXmlNode(TreeNodeCollection treeNodes, XmlNode xmlNode)
        {
            TreeNode treeNode = new TreeNode(xmlNode.Name);
            treeNode.Tag = xmlNode;
            treeNodes.Add(treeNode);
            foreach (XmlNode xmlChildNode in xmlNode.ChildNodes)
            {
                AddXmlNode(treeNode.Nodes, xmlChildNode);
            }
        }

        private void _treeView_AfterSelect(object sender, TreeViewEventArgs e)
        {
            TreeNode treeNode = e.Node;
            XmlNode xmlNode = (XmlNode) treeNode.Tag;
            _xmlAttributesViewer.XmlNode = xmlNode;
            _textBox.Text = xmlNode.Value;
            _toolStripStatusLabel.Text = GetSelectedXmlDocument().BaseURI;
        }

        private XmlDocument GetSelectedXmlDocument()
        {
            if (_treeView.SelectedNode == null)
                throw new ApplicationException("_treeView.SelectedNode == null");
            XmlNode xmlNode = (XmlNode) _treeView.SelectedNode.Tag;
            if (xmlNode is XmlDocument)
                return (XmlDocument) xmlNode;
            else
                return xmlNode.OwnerDocument;
        }
    }
}
